@@ -2,20 +2,20 @@ use strict;
 use warnings;
 
 package Lazy::Util;
-$Lazy::Util::VERSION = '0.002';
+$Lazy::Util::VERSION = '0.003';
 #ABSTRACT: Perl utilities for lazy evaluation
 
 
 use Carp qw/ croak /;
 use Exporter qw/ import /;
-use Lazy::Util::OO;
+use Lazy::Iterator;
 use Scalar::Util qw/ blessed /;
 
 use constant SCALAR_DEFER => eval { require Scalar::Defer; 1 };
 
 our @EXPORT_OK = qw/
-  l_concat l_first l_grep l_map l_nuniq l_uniq l_until g_count g_first g_join
-  g_last g_max g_min g_prod g_sum
+  l_concat l_first l_grep l_map l_until g_count g_first g_join g_last g_max
+  g_min g_prod g_sum
   /;
 
 our %EXPORT_TAGS = (all => [@EXPORT_OK],);
@@ -26,25 +26,25 @@ sub _isa { defined blessed $_[0] and $_[0]->isa($_[1]); }
 sub l_concat {
   my (@vals) = grep defined, @_;
 
-  return Lazy::Util::OO->new(sub {undef}) if @vals == 0;
+  return Lazy::Iterator->new(sub {undef}) if @vals == 0;
 
-  return $vals[0] if @vals == 1 and _isa($vals[0], 'Lazy::Util::OO');
+  return $vals[0] if @vals == 1 and _isa($vals[0], 'Lazy::Iterator');
 
-  return Lazy::Util::OO->new(
+  return Lazy::Iterator->new(
     sub {
       while (@vals) {
 
         # if it's a Scalar::Defer or a CODE reference, coerce into a
-        # Lazy::Util::OO object
-        $vals[0] = Lazy::Util::OO->new($vals[0])
+        # Lazy::Iterator object
+        $vals[0] = Lazy::Iterator->new($vals[0])
           if SCALAR_DEFER && _isa($vals[0], 0)
           or ref $vals[0] eq 'CODE';
 
-        # if by this point it's not a Lazy::Util::OO object, simply return it
+        # if by this point it's not a Lazy::Iterator object, simply return it
         # and remove from @vals
-        return shift @vals if not _isa($vals[0], 'Lazy::Util::OO');
+        return shift @vals if not _isa($vals[0], 'Lazy::Iterator');
 
-        # ->get the next value from the Lazy::Util::OO object and return it if
+        # ->get the next value from the Lazy::Iterator object and return it if
         # it's defined
         if   (defined(my $get = $vals[0]->get())) { return $get; }
         else                                      { shift @vals; }
@@ -60,7 +60,7 @@ sub l_first {
 
   my $vals = l_concat @vals;
 
-  return Lazy::Util::OO->new(
+  return Lazy::Iterator->new(
     sub {
       return $vals->get() if $n-- > 0;
       return undef;
@@ -74,7 +74,7 @@ sub l_grep (&@) {
 
   my $vals = l_concat @vals;
 
-  return Lazy::Util::OO->new(
+  return Lazy::Iterator->new(
     sub {
       while (defined(my $get = $vals->get())) {
         for ($get) {
@@ -94,7 +94,7 @@ sub l_map (&@) {
   my $vals = l_concat @vals;
 
   my @subvals = ();
-  return Lazy::Util::OO->new(
+  return Lazy::Iterator->new(
     sub {
       return shift @subvals if @subvals;
 
@@ -111,48 +111,13 @@ sub l_map (&@) {
 }
 
 
-sub l_nuniq {
-  my (@vals) = @_;
-
-  my $vals = l_concat @vals;
-
-  my %uniq;
-  return Lazy::Util::OO->new(
-    sub {
-      while (defined(my $get = $vals->get())) {
-        my $key = 0 + $get;
-        $uniq{$key}++ or return $get;
-      }
-      return undef;
-    }
-  );
-}
-
-
-sub l_uniq {
-  my (@vals) = @_;
-
-  my $vals = l_concat @vals;
-
-  my %uniq;
-  return Lazy::Util::OO->new(
-    sub {
-      while (defined(my $get = $vals->get())) {
-        $uniq{$get}++ or return $get;
-      }
-      return undef;
-    }
-  );
-}
-
-
 sub l_until (&@) {
   my ($until, @vals) = @_;
 
   my $vals = l_concat @vals;
 
   my $found = 0;
-  return Lazy::Util::OO->new(
+  return Lazy::Iterator->new(
     sub {
       return undef if $found;
 
@@ -274,7 +239,7 @@ Lazy::Util - Perl utilities for lazy evaluation
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -291,78 +256,68 @@ version 0.002
 
 =head1 DESCRIPTION
 
-Perl utility functions for lazy evalutation.
+Perl utility functions for lazy evaluation.
 
 =head1 FUNCTIONS
 
 This module has two sets of functions, the C<l_*> functions and the C<g_*>
-functions. The C<l_*> functions are designed to return a L<C<Lazy::Util::OO>>
+functions. The C<l_*> functions are designed to return a L<C<Lazy::Iterator>>
 object which you can get values from, the C<g_*> functions are designed to get
-a value out of a L<C<Lazy::Util::OO>> object. Some of the C<g_*> functions may
+a value out of a L<C<Lazy::Iterator>> object. Some of the C<g_*> functions may
 never return if the source of values is infinite, but they are for the most
 part designed to not eat up all of your memory at least ;).
 
 All these functions can be exported, but none are exported by default. You can
 use the C<:all> export tag to export all of them.
 
-=head2 C<l_*> functions
+=head1 C<l_*> functions
 
 The C<l_*> functions are:
 
-=head3 C<l_concat(@sources)>
+=head2 C<l_concat(@sources)>
 
   my $lazy = l_concat @sources;
 
-C<l_concat> returns a L<C<Lazy::Util::OO>> object which will simply return each
+C<l_concat> returns a L<C<Lazy::Iterator>> object which will simply return each
 subsequent value from the list of sources it's given.
 
-=head3 C<l_first($n, @sources)>
+=head2 C<l_first($n, @sources)>
 
   my $lazy = l_first $n, @sources;
 
-C<l_first> will return a L<C<Lazy::Util::OO>> object which will only get the first
-C<$n> values from the subsequent arguments. This can be used the 'break' an
-otherwise infinite list to only return a certain number of results.
+C<l_first> will return a L<C<Lazy::Iterator>> object which will only get the
+first C<$n> values from the subsequent arguments. This can be used the 'break'
+an otherwise infinite list to only return a certain number of results.
 
-=head3 C<l_grep($code, @sources)>
+=head2 C<l_grep($code, @sources)>
 
   my $lazy = l_grep { ... } @sources;
 
-C<l_grep> will return a L<C<Lazy::Util::OO>> object which will filter out any
+C<l_grep> will return a L<C<Lazy::Iterator>> object which will filter out any
 value which doesn't return true from the C<$code> block in the first argument.
 
-=head3 C<l_map($code, @sources)>
+=head2 C<l_map($code, @sources)>
 
   my $lazy = l_map { ... } @sources;
 
-C<l_map> will return a L<C<Lazy::Util::OO>> object which will transform any value
-using the C<$code> block in the first argument.
+C<l_map> will return a L<C<Lazy::Iterator>> object which will transform any
+value using the C<$code> block in the first argument.
 
-=head3 C<l_nuniq(@sources)>
+The C<$code> block is evaluated in list context, and each scalar it returns
+will be returned by each subsequent ->get(), not poking the C<@sources> again
+until the list is exhausted. If an empty list is returned, the C<@sources> will
+be poked again until a list of at least one element is returned, or the source
+returns C<undef>.
 
-  my $lazy = l_nuniq @sources;
-
-C<l_nuniq> will return a L<C<Lazy::Util::OO>> object which will only return
-numerically unique values from the sources. B<This has the potential to consume
-all of your memory> if the C<@sources> are infinite.
-
-=head3 C<l_uniq(@sources)>
-
-  my $lazy = l_uniq @sources;
-
-C<l_uniq> will return a L<C<Lazy::Util::OO>> object which will only return unique
-values from the sources. B<This has the potential to consume all of your
-memory> if the C<@sources> are infinite.
-
-=head3 C<l_until($code, @sources)>
+=head2 C<l_until($code, @sources)>
 
   my $lazy = l_until { ... } @sources;
 
-C<l_until> will return a L<C<Lazy::Util::OO>> object which will return values from
-the C<@sources> until the C<$code> block returns true, after which it will be
-exhausted.
+C<l_until> will return a L<C<Lazy::Iterator>> object which will return values
+from the C<@sources> until the C<$code> block returns true, after which it will
+be exhausted.
 
-=head2 C<g_*> functions
+=head1 C<g_*> functions
 
 The C<g_*> functions are:
 
@@ -374,7 +329,7 @@ C<g_count> counts the number of values from the C<@sources> and returns how
 many there were. B<This has the potential to never return> if given a source of
 infinite values.
 
-=head3 C<g_first(@sources)>
+=head2 C<g_first(@sources)>
 
   my $val = g_first @sources;
 
@@ -382,7 +337,7 @@ C<g_first> returns the first value from the list of arguments, lazily
 evaluating them. Equivalent to C<< l_concat(...)->get(); >>.
 If C<@sources> is empty, it will return C<undef>.
 
-=head3 C<g_join($sep, @sources)>
+=head2 C<g_join($sep, @sources)>
 
   my $lines = g_join $str, @sources;
 
@@ -391,7 +346,7 @@ string. B<This has the potential to never return as well as running out of
 memory> if given a source of infinite values.
 If C<@sources> is empty, it will return C<undef>.
 
-=head3 C<g_last(@sources)>
+=head2 C<g_last(@sources)>
 
   my $val = g_last @sources;
 
@@ -399,7 +354,7 @@ C<g_last> evaluates all the values it's given and returns the last value.
 B<This has the potential to never return> if given a source of infinite values.
 If C<@sources> is empty, it will return C<undef>.
 
-=head3 C<g_max(@sources)>
+=head2 C<g_max(@sources)>
 
   my $val = g_max @sources;
 
@@ -407,7 +362,7 @@ C<g_max> evaluates all the values it's given and returns the highest one.
 B<This has the potential to never return> if given a source of infinite values.
 If C<@sources> is empty, it will return C<undef>.
 
-=head3 C<g_min(@sources)>
+=head2 C<g_min(@sources)>
 
   my $val = g_min @sources;
 
@@ -415,7 +370,7 @@ C<g_min> evaluates all the values it's given and returns the lowest one. B<This
 has the potential to never return> if given a source of infinite values.
 If C<@sources> is empty, it will return C<undef>.
 
-=head3 C<g_prod(@sources)>
+=head2 C<g_prod(@sources)>
 
   my $val = g_prod @sources;
 
@@ -424,7 +379,7 @@ them. B<This has the potential to never return> if given a source of infinite
 values. Unless one of them is 0. If so, it will short-circuit and return 0.
 If C<@sources> is empty, it will return C<1>.
 
-=head3 C<g_sum(@sources)>
+=head2 C<g_sum(@sources)>
 
   my $val = g_sum @sources;
 
@@ -433,10 +388,10 @@ them. B<This has the potential to never return> if given a source of infinite
 values.
 If C<@sources> is empty, it will return C<0>.
 
-=head2 C<@sources>
+=head1 C<@sources>
 
 The C<@sources> array that most (all?) of these functions take can be any
-combination of regular scalar values, L<C<Lazy::Util::OO>> objects,
+combination of regular scalar values, L<C<Lazy::Iterator>> objects,
 L<Scalar::Defer> variables (see L</"NOTES">), or subroutine references. Each of
 these will be iterated through from start to finish, and if one of them returns
 C<undef>, the next one will be used instead, until the last one returns
@@ -479,7 +434,7 @@ Not to be confused with L<Lazy::Utils>.
 
 =over 4
 
-=item L<Lazy::Util::OO>
+=item L<Lazy::Iterator>
 
 =item L<Scalar::Defer>
 
